==> designflow_material_addon-0.0.1.tar.gz: lib/src/nodes/nodes_parse.dart <==
import 'package:designflow_widgets/designflow_widgets.dart';
import 'package:designflow_material_addon/core/node_type.dart';

import 'nodes_classes.dart';

class MaterialNodesParse extends NodesParse {
  const MaterialNodesParse(this.parent);

  final NodesParse parent;

  /// fromJson for each class using Reflectable
  @override
  CNode? fromJson(
    String widgetType,
    Map<String, dynamic> json,
    DynamicAttributes parser,
    ActionMapper actionMapper,
  ) =>
      manualFromJson(widgetType, json, parser, actionMapper);

  @override
  CNode manualFromJson(
    String widgetType,
    Map<String, dynamic> json,
    DynamicAttributes parser,
    ActionMapper actionMapper,
  ) {
    switch (widgetType) {
      case MaterialNType.materialButton:
        return MaterialButtonOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.floatingActionButton:
        return FloatingActionButtonOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.iconButton:
        return IconButtonOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.datePicker:
        return DatePickerOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.timePicker:
        return TimePickerOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.slider:
        return SliderOpenNode.fromJson(widgetType, json, parser, actionMapper);
      case MaterialNType.rangeSlider:
        return RangeSliderOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.appBar:
        return AppBarOpenNode.fromJson(widgetType, json, parser, actionMapper);
      case MaterialNType.bottomBar:
        return BottomBarOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      default:
        return parent.manualFromJson(widgetType, json, parser, actionMapper);
    }
  }
}

==> designflow_material_addon-0.0.2.tar.gz: lib/src/nodes/nodes_parse.dart <==
import 'package:designflow_widgets/designflow_widgets.dart';
import 'package:designflow_material_addon/core/node_type.dart';

import 'nodes_classes.dart';

class MaterialNodesParse extends NodesParse {
  const MaterialNodesParse(this.parent);

  final NodesParse parent;

  /// fromJson for each class using Reflectable
  @override
  CNode? fromJson(
    String widgetType,
    Map<String, dynamic> json,
    DynamicAttributes parser,
    ActionMapper actionMapper,
  ) =>
      manualFromJson(widgetType, json, parser, actionMapper);

  @override
  CNode manualFromJson(
    String widgetType,
    Map<String, dynamic> json,
    DynamicAttributes parser,
    ActionMapper actionMapper,
  ) {
    switch (widgetType) {
      case MaterialNType.materialButton:
        return MaterialButtonOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.floatingActionButton:
        return FloatingActionButtonOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.iconButton:
        return IconButtonOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.datePicker:
        return DatePickerOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.timePicker:
        return TimePickerOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      case MaterialNType.slider:
        return SliderOpenNode.fromJson(widgetType, json, parser, actionMapper);
      case MaterialNType.rangeSlider:
        return RangeSliderOpenNode.fromJson(
            widgetType, json, parser, actionMapper);
      /*case MaterialNType.appBar:
        return AppBarOpenNode.fromJson(widgetType, json, parser, actionMapper);*/
      /*case MaterialNType.bottomBar:
        return BottomBarOpenNode.fromJson(
            widgetType, json, parser, actionMapper);*/
      default:
        return parent.manualFromJson(widgetType, json, parser, actionMapper);
    }
  }
}
